Module client

Module client 

Contains clients to connect to OpenFGA:

  • OpenFgaServiceClient is the generated client that allows full control over all parameters.
  • OpenFgaClient is a wrapper around the generated client, that provides a more convenient interface and adds store_id, authorization_model_id and consistency to all requests.

Modules

batch_check_single_result
Nested message and enum types in BatchCheckSingleResult.
check_error
Nested message and enum types in CheckError.
condition_param_type_ref
Nested message and enum types in ConditionParamTypeRef.
open_fga_service_client
Generated client implementations.
relation_reference
Nested message and enum types in RelationReference.
user
Nested message and enum types in User.
userset
Nested message and enum types in Userset.
userset_tree
Nested message and enum types in UsersetTree.

Structs

AbortedMessageResponse
Assertion
AssertionTupleKey
Assertions
AuthorizationModel
BatchCheckItem
BatchCheckRequest
BatchCheckResponse
BatchCheckSingleResult
CheckError
CheckRequest
CheckRequestTupleKey
CheckResponse
ComputedUserset
Condition
ConditionMetadata
ConditionParamTypeRef
ContextualTupleKeys
CreateStoreRequest
CreateStoreResponse
DeleteStoreRequest
DeleteStoreResponse
Difference
DirectUserset
A DirectUserset is a sentinel message for referencing the direct members specified by an object/relation mapping.
ErrorMessageRequest
ExpandRequest
ExpandRequestTupleKey
ExpandResponse
ForbiddenResponse
GetStoreRequest
GetStoreResponse
InternalErrorMessageResponse
ListObjectsRequest
ListObjectsResponse
ListStoresRequest
ListStoresResponse
ListUsersRequest
ListUsersResponse
Metadata
Object
Object represents an OpenFGA Object.
ObjectRelation
OpenFgaClient
Wrapper around the generated OpenFgaServiceClient.
OpenFgaServiceClient
PathUnknownErrorMessageResponse
ReadAssertionsRequest
ReadAssertionsResponse
ReadAuthorizationModelRequest
ReadAuthorizationModelResponse
ReadAuthorizationModelsRequest
ReadAuthorizationModelsResponse
ReadChangesRequest
ReadChangesResponse
ReadRequest
ReadRequestTupleKey
ReadResponse
Relation
RelationMetadata
RelationReference
RelationReference represents a relation of a particular object type (e.g. ‘document#viewer’).
RelationTypeInfo
RelationshipCondition
SourceInfo
Store
StreamedListObjectsRequest
StreamedListObjectsResponse
The response for a StreamedListObjects RPC.
Tuple
TupleChange
TupleKey
TupleKeyWithoutCondition
TupleKeys
TupleToUserset
TypeDefinition
TypedWildcard
Type bound public access.
UnauthenticatedResponse
UnprocessableContentMessageResponse
UpdateStoreRequest
UpdateStoreResponse
User
User.
UserTypeFilter
Userset
UsersetTree
A UsersetTree contains the result of an Expansion.
UsersetUser
Userset.
Usersets
ValidationErrorMessageResponse
Wildcard
WriteAssertionsRequest
WriteAssertionsResponse
WriteAuthorizationModelRequest
WriteAuthorizationModelResponse
WriteOptions
Options for write operations.
WriteRequest
WriteRequestDeletes
WriteRequestWrites
WriteResponse

Enums

AuthErrorCode
ConflictBehavior
Behavior when encountering conflicts during write operations.
ConsistencyPreference
Controls the consistency preferences when calling the query APIs.
ErrorCode
InternalErrorCode
NotFoundErrorCode
TupleOperation
buf:lint:ignore ENUM_ZERO_VALUE_SUFFIX
UnprocessableContentErrorCode

Constants

FILE_DESCRIPTOR_SET
Encoded file descriptor set for the openfga.v1 package