#[repr(i32)]pub enum AuthErrorCode {
NoAuthError = 0,
AuthFailedInvalidSubject = 1_001,
AuthFailedInvalidAudience = 1_002,
AuthFailedInvalidIssuer = 1_003,
InvalidClaims = 1_004,
AuthFailedInvalidBearerToken = 1_005,
BearerTokenMissing = 1_010,
Unauthenticated = 1_500,
Forbidden = 1_600,
}Variants
NoAuthError = 0
AuthFailedInvalidSubject = 1_001
AuthFailedInvalidAudience = 1_002
AuthFailedInvalidIssuer = 1_003
InvalidClaims = 1_004
AuthFailedInvalidBearerToken = 1_005
BearerTokenMissing = 1_010
Unauthenticated = 1_500
Forbidden = 1_600
Implementations
Sourceimpl AuthErrorCode
impl AuthErrorCode
Sourceimpl AuthErrorCode
impl AuthErrorCode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.