#[repr(i32)]pub enum ConsistencyPreference {
Unspecified = 0,
MinimizeLatency = 100,
HigherConsistency = 200,
}Expand description
Controls the consistency preferences when calling the query APIs.
Variants
Unspecified = 0
Default if not set. Behavior will be the same as MINIMIZE_LATENCY.
MinimizeLatency = 100
Minimize latency at the potential expense of lower consistency.
HigherConsistency = 200
Prefer higher consistency, at the potential expense of increased latency.
Implementations
Sourceimpl ConsistencyPreference
impl ConsistencyPreference
Sourcepub fn is_valid(value: i32) -> bool
pub fn is_valid(value: i32) -> bool
Returns true if value is a variant of ConsistencyPreference.
Sourcepub fn from_i32(value: i32) -> Option<ConsistencyPreference>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ConsistencyPreference>
Converts an i32 to a ConsistencyPreference, or None if value is not a valid variant.
Sourceimpl ConsistencyPreference
impl ConsistencyPreference
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.