#[repr(i32)]pub enum ErrorCode {
Show 50 variants
NoError = 0,
ValidationError = 2_000,
AuthorizationModelNotFound = 2_001,
AuthorizationModelResolutionTooComplex = 2_002,
InvalidWriteInput = 2_003,
CannotAllowDuplicateTuplesInOneRequest = 2_004,
CannotAllowDuplicateTypesInOneRequest = 2_005,
CannotAllowMultipleReferencesToOneRelation = 2_006,
InvalidContinuationToken = 2_007,
InvalidTupleSet = 2_008,
InvalidCheckInput = 2_009,
InvalidExpandInput = 2_010,
UnsupportedUserSet = 2_011,
InvalidObjectFormat = 2_012,
WriteFailedDueToInvalidInput = 2_017,
AuthorizationModelAssertionsNotFound = 2_018,
LatestAuthorizationModelNotFound = 2_020,
TypeNotFound = 2_021,
RelationNotFound = 2_022,
EmptyRelationDefinition = 2_023,
InvalidUser = 2_025,
InvalidTuple = 2_027,
UnknownRelation = 2_028,
StoreIdInvalidLength = 2_030,
AssertionsTooManyItems = 2_033,
IdTooLong = 2_034,
AuthorizationModelIdTooLong = 2_036,
TupleKeyValueNotSpecified = 2_037,
TupleKeysTooManyOrTooFewItems = 2_038,
PageSizeInvalid = 2_039,
ParamMissingValue = 2_040,
DifferenceBaseMissingValue = 2_041,
SubtractBaseMissingValue = 2_042,
ObjectTooLong = 2_043,
RelationTooLong = 2_044,
TypeDefinitionsTooFewItems = 2_045,
TypeInvalidLength = 2_046,
TypeInvalidPattern = 2_047,
RelationsTooFewItems = 2_048,
RelationsTooLong = 2_049,
RelationsInvalidPattern = 2_050,
ObjectInvalidPattern = 2_051,
QueryStringTypeContinuationTokenMismatch = 2_052,
ExceededEntityLimit = 2_053,
InvalidContextualTuple = 2_054,
DuplicateContextualTuple = 2_055,
InvalidAuthorizationModel = 2_056,
UnsupportedSchemaVersion = 2_057,
Cancelled = 2_058,
InvalidStartTime = 2_059,
}Variants
NoError = 0
ValidationError = 2_000
AuthorizationModelNotFound = 2_001
AuthorizationModelResolutionTooComplex = 2_002
InvalidWriteInput = 2_003
CannotAllowDuplicateTuplesInOneRequest = 2_004
CannotAllowDuplicateTypesInOneRequest = 2_005
CannotAllowMultipleReferencesToOneRelation = 2_006
InvalidContinuationToken = 2_007
InvalidTupleSet = 2_008
InvalidCheckInput = 2_009
InvalidExpandInput = 2_010
UnsupportedUserSet = 2_011
InvalidObjectFormat = 2_012
WriteFailedDueToInvalidInput = 2_017
AuthorizationModelAssertionsNotFound = 2_018
LatestAuthorizationModelNotFound = 2_020
TypeNotFound = 2_021
RelationNotFound = 2_022
EmptyRelationDefinition = 2_023
InvalidUser = 2_025
InvalidTuple = 2_027
UnknownRelation = 2_028
StoreIdInvalidLength = 2_030
AssertionsTooManyItems = 2_033
IdTooLong = 2_034
AuthorizationModelIdTooLong = 2_036
TupleKeyValueNotSpecified = 2_037
TupleKeysTooManyOrTooFewItems = 2_038
PageSizeInvalid = 2_039
ParamMissingValue = 2_040
DifferenceBaseMissingValue = 2_041
SubtractBaseMissingValue = 2_042
ObjectTooLong = 2_043
RelationTooLong = 2_044
TypeDefinitionsTooFewItems = 2_045
TypeInvalidLength = 2_046
TypeInvalidPattern = 2_047
RelationsTooFewItems = 2_048
RelationsTooLong = 2_049
RelationsInvalidPattern = 2_050
ObjectInvalidPattern = 2_051
QueryStringTypeContinuationTokenMismatch = 2_052
ExceededEntityLimit = 2_053
InvalidContextualTuple = 2_054
DuplicateContextualTuple = 2_055
InvalidAuthorizationModel = 2_056
UnsupportedSchemaVersion = 2_057
Cancelled = 2_058
InvalidStartTime = 2_059
Implementations
Sourceimpl ErrorCode
impl ErrorCode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.