#[repr(i32)]pub enum InternalErrorCode {
NoInternalError = 0,
InternalError = 4_000,
DeadlineExceeded = 4_004,
AlreadyExists = 4_005,
ResourceExhausted = 4_006,
FailedPrecondition = 4_007,
Aborted = 4_008,
OutOfRange = 4_009,
Unavailable = 4_010,
DataLoss = 4_011,
}Variants
NoInternalError = 0
InternalError = 4_000
DeadlineExceeded = 4_004
AlreadyExists = 4_005
ResourceExhausted = 4_006
FailedPrecondition = 4_007
Aborted = 4_008
OutOfRange = 4_009
DataLoss = 4_011
Implementations
Sourceimpl InternalErrorCode
impl InternalErrorCode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.