pub struct BatchCheckRequest {
pub store_id: String,
pub checks: Vec<BatchCheckItem>,
pub authorization_model_id: String,
pub consistency: i32,
}Fields
store_id: Stringchecks: Vec<BatchCheckItem>consistency: i32Implementations
Sourceimpl BatchCheckRequest
impl BatchCheckRequest
Sourcepub fn consistency(&self) -> ConsistencyPreference
pub fn consistency(&self) -> ConsistencyPreference
Returns the enum value of consistency, or the default if the field is set to an invalid enum value.
Sourcepub fn set_consistency(&mut self, value: ConsistencyPreference)
pub fn set_consistency(&mut self, value: ConsistencyPreference)
Sets consistency to the provided enum value.