pub struct CheckRequest {
pub store_id: String,
pub tuple_key: Option<CheckRequestTupleKey>,
pub contextual_tuples: Option<ContextualTupleKeys>,
pub authorization_model_id: String,
pub trace: bool,
pub context: Option<Struct>,
pub consistency: i32,
}Fields
store_id: Stringtuple_key: Option<CheckRequestTupleKey>contextual_tuples: Option<ContextualTupleKeys>trace: boolDefaults to false. Making it true has performance implications.
context: Option<Struct>Additional request context that will be used to evaluate any ABAC conditions encountered in the query evaluation.
consistency: i32Controls the consistency preference for this request. Default value is UNSPECIFIED, which will have the same behavior as MINIMIZE_LATENCY.
Implementations
Sourceimpl CheckRequest
impl CheckRequest
Sourcepub fn consistency(&self) -> ConsistencyPreference
pub fn consistency(&self) -> ConsistencyPreference
Returns the enum value of consistency, or the default if the field is set to an invalid enum value.
Sourcepub fn set_consistency(&mut self, value: ConsistencyPreference)
pub fn set_consistency(&mut self, value: ConsistencyPreference)
Sets consistency to the provided enum value.