pub struct CheckRequestTupleKey {
pub user: String,
pub relation: String,
pub object: String,
}Fields
user: Stringrelation: Stringobject: StringTrait Implementations
Sourceimpl Clone for CheckRequestTupleKey
impl Clone for CheckRequestTupleKey
Sourcefn clone(&self) -> CheckRequestTupleKey
fn clone(&self) -> CheckRequestTupleKey
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CheckRequestTupleKey
impl Debug for CheckRequestTupleKey
Sourceimpl Default for CheckRequestTupleKey
impl Default for CheckRequestTupleKey
impl<'de> Deserialize<'de> for CheckRequestTupleKey
impl<'de> Deserialize<'de> for CheckRequestTupleKey
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<CheckRequestTupleKey> for Option<TupleKeyWithoutCondition>
impl From<CheckRequestTupleKey> for Option<TupleKeyWithoutCondition>
Sourcefn from(tuple_key: CheckRequestTupleKey) -> Self
fn from(tuple_key: CheckRequestTupleKey) -> Self
Converts to this type from the input type.
Sourceimpl From<CheckRequestTupleKey> for TupleKeyWithoutCondition
impl From<CheckRequestTupleKey> for TupleKeyWithoutCondition
Sourcefn from(tuple_key: CheckRequestTupleKey) -> Self
fn from(tuple_key: CheckRequestTupleKey) -> Self
Converts to this type from the input type.
Sourceimpl From<TupleKeyWithoutCondition> for CheckRequestTupleKey
impl From<TupleKeyWithoutCondition> for CheckRequestTupleKey
Sourcefn from(tuple_key: TupleKeyWithoutCondition) -> Self
fn from(tuple_key: TupleKeyWithoutCondition) -> Self
Converts to this type from the input type.
Sourceimpl Hash for CheckRequestTupleKey
impl Hash for CheckRequestTupleKey
Sourceimpl Message for CheckRequestTupleKey
impl Message for CheckRequestTupleKey
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for CheckRequestTupleKey
impl PartialEq for CheckRequestTupleKey
impl Serialize for CheckRequestTupleKey
impl Serialize for CheckRequestTupleKey
impl Eq for CheckRequestTupleKey
impl StructuralPartialEq for CheckRequestTupleKey