pub struct ForbiddenResponse {
pub code: i32,
pub message: String,
}Fields
code: i32message: StringImplementations
Sourceimpl ForbiddenResponse
impl ForbiddenResponse
Sourcepub fn code(&self) -> AuthErrorCode
pub fn code(&self) -> AuthErrorCode
Returns the enum value of code, or the default if the field is set to an invalid enum value.
Sourcepub fn set_code(&mut self, value: AuthErrorCode)
pub fn set_code(&mut self, value: AuthErrorCode)
Sets code to the provided enum value.