pub struct InternalErrorMessageResponse {
pub code: i32,
pub message: String,
}Fields
code: i32message: StringImplementations
Sourceimpl InternalErrorMessageResponse
impl InternalErrorMessageResponse
Sourcepub fn code(&self) -> InternalErrorCode
pub fn code(&self) -> InternalErrorCode
Returns the enum value of code, or the default if the field is set to an invalid enum value.
Sourcepub fn set_code(&mut self, value: InternalErrorCode)
pub fn set_code(&mut self, value: InternalErrorCode)
Sets code to the provided enum value.