pub struct ListUsersRequest {
pub store_id: String,
pub authorization_model_id: String,
pub object: Option<Object>,
pub relation: String,
pub user_filters: Vec<UserTypeFilter>,
pub contextual_tuples: Vec<TupleKey>,
pub context: Option<Struct>,
pub consistency: i32,
}Fields
store_id: Stringobject: Option<Object>relation: Stringuser_filters: Vec<UserTypeFilter>contextual_tuples: Vec<TupleKey>context: Option<Struct>Additional request context that will be used to evaluate any ABAC conditions encountered in the query evaluation.
consistency: i32Controls the consistency preference for this request. Default value is UNSPECIFIED, which will have the same behavior as MINIMIZE_LATENCY.
Implementations
Sourceimpl ListUsersRequest
impl ListUsersRequest
Sourcepub fn consistency(&self) -> ConsistencyPreference
pub fn consistency(&self) -> ConsistencyPreference
Returns the enum value of consistency, or the default if the field is set to an invalid enum value.
Sourcepub fn set_consistency(&mut self, value: ConsistencyPreference)
pub fn set_consistency(&mut self, value: ConsistencyPreference)
Sets consistency to the provided enum value.