pub struct PathUnknownErrorMessageResponse {
pub code: i32,
pub message: String,
}Fields
code: i32message: StringImplementations
Sourceimpl PathUnknownErrorMessageResponse
impl PathUnknownErrorMessageResponse
Sourcepub fn code(&self) -> NotFoundErrorCode
pub fn code(&self) -> NotFoundErrorCode
Returns the enum value of code, or the default if the field is set to an invalid enum value.
Sourcepub fn set_code(&mut self, value: NotFoundErrorCode)
pub fn set_code(&mut self, value: NotFoundErrorCode)
Sets code to the provided enum value.