pub struct ReadRequest {
pub store_id: String,
pub tuple_key: Option<ReadRequestTupleKey>,
pub page_size: Option<i32>,
pub continuation_token: String,
pub consistency: i32,
}Fields
store_id: Stringtuple_key: Option<ReadRequestTupleKey>page_size: Option<i32>continuation_token: Stringconsistency: i32Controls the consistency preference for this request. Default value is UNSPECIFIED, which will have the same behavior as MINIMIZE_LATENCY.
Implementations
Sourceimpl ReadRequest
impl ReadRequest
Sourcepub fn consistency(&self) -> ConsistencyPreference
pub fn consistency(&self) -> ConsistencyPreference
Returns the enum value of consistency, or the default if the field is set to an invalid enum value.
Sourcepub fn set_consistency(&mut self, value: ConsistencyPreference)
pub fn set_consistency(&mut self, value: ConsistencyPreference)
Sets consistency to the provided enum value.