pub struct RelationshipCondition {
pub name: String,
pub context: Option<Struct>,
}Fields
name: StringA reference (by name) of the relationship condition defined in the authorization model.
context: Option<Struct>Additional context/data to persist along with the condition. The keys must match the parameters defined by the condition, and the value types must match the parameter type definitions.