pub struct TupleChange {
pub tuple_key: Option<TupleKey>,
pub operation: i32,
pub timestamp: Option<Timestamp>,
}Fields
tuple_key: Option<TupleKey>operation: i32timestamp: Option<Timestamp>Implementations
Sourceimpl TupleChange
impl TupleChange
Sourcepub fn operation(&self) -> TupleOperation
pub fn operation(&self) -> TupleOperation
Returns the enum value of operation, or the default if the field is set to an invalid enum value.
Sourcepub fn set_operation(&mut self, value: TupleOperation)
pub fn set_operation(&mut self, value: TupleOperation)
Sets operation to the provided enum value.