pub struct TypeDefinition {
pub type: String,
pub relations: HashMap<String, Userset>,
pub metadata: Option<Metadata>,
}Fields
type: Stringrelations: HashMap<String, Userset>metadata: Option<Metadata>A map whose keys are the name of the relation and whose value is the Metadata for that relation. It also holds information around the module name and source file if this model was constructed from a modular model.