pub enum Error {
Show 13 variants
AmbiguousStoreName(String),
RequestFailed(Box<Status>),
TooManyPages {
max_pages: u32,
tuple: Option<ReadRequestTupleKey>,
},
InvalidEndpoint(String),
InvalidToken {
reason: String,
},
InvalidModelVersion(String),
MigrationHookFailed {
version: String,
error: Arc<StdError>,
},
MissingAuthorizationModelId {
model_prefix: String,
version: String,
},
StoreNotFound(String),
AmbiguousModelVersion {
model_prefix: String,
version: String,
},
TooManyWrites {
actual: i32,
max: i32,
},
ExpectedOneof,
TlsConfigurationFailed {
endpoint: String,
reason: String,
},
}Variants
AmbiguousStoreName(String)
RequestFailed(Box<Status>)
TooManyPages
InvalidEndpoint(String)
InvalidToken
InvalidModelVersion(String)
MigrationHookFailed
MissingAuthorizationModelId
StoreNotFound(String)
AmbiguousModelVersion
TooManyWrites
ExpectedOneof
Protobuf oneof fields are always wrapped in an Option by prost (ref).
ExpectedOneof is raised if OpenFGA is expected to return one of the variants
(i.e. Some(T)) but instead None was received.
TlsConfigurationFailed