Enum Error

pub enum Error {
    AmbiguousStoreName(String),
    RequestFailed(Status),
    TooManyPages {
        max_pages: u32,
        tuple: ReadRequestTupleKey,
    },
    InvalidEndpoint(String),
    InvalidToken {
        reason: String,
    },
    InvalidModelVersion(String),
    MigrationHookFailed {
        version: String,
        error: Arc<StdError>,
    },
    StoreNotFound(String),
    AmbiguousModelVersion {
        model_prefix: String,
        version: String,
    },
    TooManyWrites {
        actual: i32,
        max: i32,
    },
    ExpectedOneof,
}

Variants



AmbiguousStoreName(String)



RequestFailed(Status)



TooManyPages

Fields

max_pages: u32


InvalidEndpoint(String)



InvalidToken

Fields

reason: String


InvalidModelVersion(String)



MigrationHookFailed

Fields

version: String
error: Arc<StdError>


StoreNotFound(String)



AmbiguousModelVersion

Fields

model_prefix: String
version: String


TooManyWrites

Fields

actual: i32
max: i32


ExpectedOneof

Protobuf oneof fields are always wrapped in an Option by prost (ref). ExpectedOneof is raised if OpenFGA is expected to return one of the variants (i.e. Some(T)) but instead None was received.